@@ -61,7 +61,7 @@ use Scalar::Util ();
 
 use vars qw{$VERSION @EXPORT_OK %EXPORT_TAGS};
 BEGIN {
-	$VERSION   = '0.10';
+	$VERSION   = '0.11';
 
 	@EXPORT_OK = qw{
 		_STRING     _IDENTIFIER _CLASS
@@ -147,7 +147,7 @@ C<undef> if not.
 =cut
 
 sub _CLASS ($) {
-	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::[^\W\d]\w*)*$/s) ? $_[0] : undef;
+	(defined $_[0] and ! ref $_[0] and $_[0] =~ m/^[^\W\d]\w*(?:::\w+)*$/s) ? $_[0] : undef;
 }
 
 =pod
